@@ -54,10 +54,6 @@ namespace Oxygen
         //! depth adjustment hook
         static gboolean styleHook( GSignalInvocationHint*, guint, const GValue*, gpointer );
 
-        //! error handler
-        /*! it is used to disable printing out some messages triggered by the style hook when deleting combobox-entry */
-        static void logHandler( const gchar*, GLogLevelFlags, const gchar*, gpointer );
-
         private:
 
         //! true if hooks are initialized
@@ -69,9 +65,6 @@ namespace Oxygen
         //! style hook
         Hook _styleHook;
 
-        //! log handler id
-        guint _logId;
-
     };
 
 }
